# -*- coding: utf-8 -*-
"""
    ezsocket.vblapi.py

    This file contains the functionality used to consume the VBL's Data API.

"""

import requests
import json

from datetime import datetime
from pytz import timezone

from .exceptions import VBLAPIException
from .utility import parse_int


class VBLAPI:
    """API wrapper for the public API of the 'Vlaamse Basketbal Liga'.
    """
    BASE_URL = "http://vblcb.wisseq.eu/VBLCB_WebService/data/"

    def _get_request(self, url):
        """ Sends GET request to given url, and returns the JSON response.
        """
        try:
            response = requests.get(url)
        except requests.exceptions.RequestException as e:
            raise VBLAPIException(
                "Exceptional situation occurred while using VBL API: {0}"
                .format(e)
            )
        try:
            response.raise_for_status()
        except requests.exceptions.HTTPError as e:
            raise VBLAPIException(
                "Exceptional situation occurred while using VBL API: {0}"
                .format(e)
            )
        try:
            return json.loads(response.text)
        except:
            raise VBLAPIException(
                "Exceptional situation occurred while using VBL API: "
                "Unable to convert response content to JSON: {0}"
                .format(response.text)
            )

    def get_team_competition(self, guid):
        """ Returns competition information about a given team.
        """
        url = self.BASE_URL + 'TeamDetailByGuid?teamGuid=' + guid
        r = self._get_request(url)
        if not r:
            raise VBLAPIException(
                "Exceptional situation occured while using VBL API: "
                "No competition information related to this team found."
            )
        comp = [c for c in r[0]['poules']
            if ('OEFEN' not in c['naam']) and ('BEKER' not in c['naam'])
        ][0]
        competition = [
            {
                'rank':         parse_int(t['rangNr']),             
                'name':         t['naam'],
                'games':        parse_int(t['wedAant']),
                'wins':         parse_int(t['wedWinst']),
                'losses':       parse_int(t['wedVerloren']),                
                'draws':        parse_int(t['wedGelijk']),
                'rankPoints':   parse_int(t['wedPunt']),
                'pointsScored': parse_int(t['ptVoor']),
                'pointsTaken':  parse_int(t['ptTegen']),
                'note':         t['opmerk']
            } 
            for t in comp['teams']
        ]
        return competition


    def get_team_matches(self, guid):
        """Returns match information about a given team.
        """
        url = self.BASE_URL + 'TeamMatchesByGuid?teamGuid='+ guid
        r = self._get_request(url)
        if not r:
            raise VBLAPIException(
                "Exceptional situation occured while using VBL API: "
                "No match information related to this team found."
            )
        ms = [m for m in r if 'OEFEN' not in m['pouleNaam']]
        ms = [
            {
                'datetime':     datetime(
                                    parse_int(m['datumString'].split('-')[2]),
                                    parse_int(m['datumString'].split('-')[1]),
                                    parse_int(m['datumString'].split('-')[0]),
                                    parse_int(m['beginTijd'].split('.')[0]),
                                    parse_int(m['beginTijd'].split('.')[1]),
                                    tzinfo=timezone('Europe/Brussels')
                                ),
                'location':     m['accNaam'],
                'home':         m['tTNaam'],
                'visitors':     m['tUNaam'],
                'scoreH':       None if m['uitslag'] == '' else parse_int(
                                    m['uitslag']
                                    .replace(' ', '')
                                    .split('-')[0]
                                ),
                'scoreV':       None if m['uitslag'] == '' else parse_int(
                                    m['uitslag']
                                    .replace(' ', '')
                                    .replace('BFOR', '')
                                    .split('-')[1]
                                ),
                'forfait':      'FOR' in m['uitslag'],
                'bekermatch':   'Beker' in m['pouleNaam']
            }
            for m in ms
        ]
        ms = sorted(ms, key=lambda match: match['datetime'])
        return ms

